﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Steema.TeeChart.WPF.Drawing;

namespace TestTChart
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public enum EOTLFigure
        {
            eDIAmond = 0, // filled diamond
            eTransparentDiamond = 1, // Transparent Big Diamond
            eSmallDiamond = 2, // Point figure
            eTransparentSmallDiamond = 3, // Transparent small Diamond
            eUpHalfDiamond = 4, // Romb Up
            eDownHalfDiamond = 5, // Romb Down
            eCrossDiagonal = 6, // X over diamond
            eOverlap = 7, // overlap
            eValidated = 8, // Continues Validate
            eInitiated = 9, // Continues Initiated
            eChangeUpSeries = 10, // triangle up
            eChangeDownSeries = 11, // triangle down
            eCardexedChangeUpSeries = 12, // black triangle up
            eCardexedChangeDownSeries = 13, // black triangle down
            //// Must be last items
            ePending = 14, // Continues Pending
            eCardexedStartStopPauseResume = 15, // vertical dot line
            eStartStopPauseResume = 16, // Stop Start, Pause , Resume
            eProblematic = 17 // continuous problematic
        }
        private enum enSymbol
        {
            psRectangle = 0,
            psCircle = 1,
            psTriangle = 2,
            psDownTriangle = 3,
            psCross = 4,
            psDiagCross = 5,
            psStar = 6,
            psDiamond = 7,
            psSmallDot = 8,
            psTriangleWithLine = 9,
            psDownTriangleWithLine = 10,
            psOpenTriangle = 11,
            psOpenDownTriangle = 12
        }


        private const int BASE_X = 1024;
        private const int BASE_Y = 768;
        private const int SPACE_WIDTH = 1;
        private const int DV_NAME_WIDTH = 21;

        public const double CORNER_RADIUS = 10;
        public const double MARGING_LEFT = 12;
        public const double MARGING_RIGHT = 8;
        public const double MARGING_TOP = CORNER_RADIUS / 3;
        public const double MARGING_BOTTOM = CORNER_RADIUS / 2;

        public const double EDIT_BUTTON_SIZE = 17;
        public const double SCROLL_WIDTH = 19;
        public const double CAPTION_THICKNESS = 33;

        public const double MARGING_INSIDE_RIGHT = 2;
        public const double MARGING_INSIDE_SMALL = 2;
        public const double MARGING_INSIDE_LEFT = CAPTION_THICKNESS - MARGING_LEFT + MARGING_INSIDE_SMALL * 2;

        private int m_lIconSize = 6;
        private int m_iRowHight = 21;
        private int m_lDefaulRowNumber;
        private int m_iVisiblesRows = 0;

        public MainWindow()
        {
            InitializeComponent();
        }

        private void InitTChartProperties()
        {
            // 
            // tChartConcrol
            // 
            Canvas.SetLeft(tChartConcrol, 8);
            Canvas.SetTop(tChartConcrol, 36);
            this.tChartConcrol.Name = "tChartConcrol";
            this.tChartConcrol.TabIndex = 2;
            this.tChartConcrol.Aspect.View3D = false;
            this.tChartConcrol.Aspect.ZOffset = 0;
            this.tChartConcrol.Axes.Bottom.Automatic = false;
            this.tChartConcrol.Axes.Bottom.AutomaticMaximum = false;
            this.tChartConcrol.Axes.Bottom.AutomaticMinimum = false;
            this.tChartConcrol.Axes.Bottom.Grid.Visible = false;
            this.tChartConcrol.Axes.Bottom.Labels.Visible = false;
            this.tChartConcrol.Axes.Bottom.Maximum = 12;
            this.tChartConcrol.Axes.Bottom.Minimum = 0;
            this.tChartConcrol.Axes.Bottom.RelativePosition = -13;
            this.tChartConcrol.Axes.Bottom.Ticks.Length = 0;
            this.tChartConcrol.Axes.Bottom.Ticks.Visible = false;
            this.tChartConcrol.Axes.Left.Automatic = false;
            this.tChartConcrol.Axes.Left.AutomaticMaximum = false;
            this.tChartConcrol.Axes.Left.AutomaticMinimum = false;
            this.tChartConcrol.Axes.Left.Grid.Visible = false;
            this.tChartConcrol.Axes.Left.Labels.CustomSize = 10;
            this.tChartConcrol.Axes.Left.Labels.Style = Steema.TeeChart.WPF.AxisLabelStyle.None;
            this.tChartConcrol.Axes.Left.Maximum = 10;
            this.tChartConcrol.Axes.Left.Minimum = 0;
            this.tChartConcrol.Axes.Left.MinorTicks.Visible = false;
            this.tChartConcrol.Axes.Left.Ticks.Visible = false;
            this.tChartConcrol.Axes.Right.Labels.CustomSize = 80;
            this.tChartConcrol.Axes.Right.Labels.Style = Steema.TeeChart.WPF.AxisLabelStyle.None;
            this.tChartConcrol.Axes.Right.MinorTicks.Visible = false;
            this.tChartConcrol.Axes.Right.Ticks.Visible = false;
            this.tChartConcrol.Axes.Top.Automatic = false;
            this.tChartConcrol.Axes.Top.AutomaticMaximum = false;
            this.tChartConcrol.Axes.Top.AutomaticMinimum = false;
            this.tChartConcrol.Axes.Top.Maximum = 12;
            this.tChartConcrol.Axes.Top.Minimum = 0;
            this.tChartConcrol.Background = Brushes.Transparent;
            this.tChartConcrol.Header.Font.Bold = true;
            this.tChartConcrol.Header.Font.Brush.Color =
                Color.FromRgb(((int) (((byte) (64)))), ((int) (((byte) (0)))), ((int) (((byte) (128)))));
            this.tChartConcrol.Header.Lines = new string[] {"Mv Or Order pack control"};
            this.tChartConcrol.Legend.Visible = false;
            this.tChartConcrol.Panel.Bevel.Outer = Steema.TeeChart.WPF.Drawing.BevelStyles.None;
            this.tChartConcrol.Panel.Brush.Color = Colors.Silver;
            this.tChartConcrol.Panel.Brush.Gradient.StartColor = Colors.White;
            this.tChartConcrol.Panel.Brush.Gradient.UseMiddle = false;
            this.tChartConcrol.Panel.Brush.Gradient.Visible = false;
            this.tChartConcrol.Panel.MarginBottom = 1;
            this.tChartConcrol.Panel.MarginLeft = 0;
            this.tChartConcrol.Panel.MarginRight = 0;
            this.tChartConcrol.Panel.MarginTop = 0;
            this.tChartConcrol.Panning.Allow = Steema.TeeChart.WPF.ScrollModes.None;
            this.tChartConcrol.Walls.Back.Brush.Gradient.Visible = false;
            this.tChartConcrol.Walls.Back.Brush.Visible = false;
            this.tChartConcrol.Walls.Back.Transparent = true;
            this.tChartConcrol.Zoom.Allow = false;
            this.tChartConcrol.Visibility = Visibility.Visible;
            this.tChartConcrol.Width = 10;
            this.tChartConcrol.Height = 10;
            this.tChartConcrol.Graphics3D.UseGuidelines = true;
            tChartConcrol.FocusVisualStyle = null;
        }

        private void ResizeViewControls()
        {


            Canvas.SetLeft(picScroll, Convert.ToInt32(Canvas.GetLeft(this)));
            Canvas.SetTop(picScroll, Convert.ToInt32(Canvas.GetTop(this)));
            double picScrollWidth = base.ActualWidth - 50 - MARGING_INSIDE_RIGHT - MARGING_INSIDE_SMALL;
            picScroll.Width = picScrollWidth < 0 ? 0 : picScrollWidth;
            picScroll.Height = (int)base.ActualHeight;
            picScroll.Visibility = Visibility.Visible;

            if ((int)Canvas.GetLeft(this) != 0 || (int)Canvas.GetTop(this) != 0 ||
                tChartConcrol.Width != picScroll.Width ||
                tChartConcrol.Chart.Width != picScroll.Width)
            //tChartConcrol.Height != picScroll.Height || tChartConcrol.Chart.Height != picScroll.Height
            {
                Canvas.SetLeft(tChartConcrol, 0);
                Canvas.SetTop(tChartConcrol, 0);
                tChartConcrol.Width = picScroll.Width;
                tChartConcrol.Height = picScroll.Height;
                tChartConcrol.Chart.Width = picScroll.Width;
                tChartConcrol.Chart.Height = picScroll.Height;
            }

        }

        private void SetTChartDefaults()
        {
            double iRightMarginWidth = default(double);
            double iLeftMarginWidth = default(double);

            if (tChartConcrol.Header.Lines == null || tChartConcrol.Header.Lines.Length == 0)
            {
                tChartConcrol.Header.Lines = new string[] {""};
            }
            tChartConcrol.Header.Lines[0] = "";
            tChartConcrol.Header.Visible = false;
            Canvas.SetLeft(tChartConcrol, 0);

            tChartConcrol.Panel.Color = Color.FromRgb(255, 255, 255);
            tChartConcrol.Panel.MarginLeft = 0;
            tChartConcrol.Panel.MarginRight = 0;
            tChartConcrol.Panel.MarginBottom = 0;
            tChartConcrol.Panel.MarginTop = 0;

            tChartConcrol.Axes.Bottom.Automatic = false;
            tChartConcrol.Axes.Bottom.AutomaticMaximum = false;
            tChartConcrol.Axes.Bottom.AutomaticMinimum = false;

            tChartConcrol.Axes.Left.MinorGrid.Visible = false;
            tChartConcrol.Axes.Left.Ticks.Visible = false;
            tChartConcrol.Axes.Left.MinorTicks.Visible = false;
            tChartConcrol.Axes.Left.AutomaticMaximum = false;
            tChartConcrol.Axes.Left.AutomaticMinimum = false;
            tChartConcrol.Axes.Left.Inverted = true;
            tChartConcrol.Axes.Left.Visible = true;
            tChartConcrol.Axes.Left.AxisPen.Visible = false;


            tChartConcrol.Axes.Top.Visible = false;

            tChartConcrol.Axes.Right.Inverted = true;
            tChartConcrol.Axes.Right.Visible = true;
            tChartConcrol.Axes.Right.AxisPen.Visible = false;

            tChartConcrol.Zoom.Allow = false;
            tChartConcrol.Panning.Allow = Steema.TeeChart.WPF.ScrollModes.None;

        }

        public void CreateTchartSeries()
        {
            tChartConcrol.Series.Clear();

            tChartConcrol.Series.Add(new Steema.TeeChart.WPF.Styles.Points(tChartConcrol.Chart));
            //// Big filled diamond
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eDIAmond]).Pointer.Style =
                (Steema.TeeChart.WPF.Styles.PointerStyles) enSymbol.psDiamond;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eDIAmond]).Pointer.VertSize = m_lIconSize;
            //IIf(m_lIconSize > 5, 5, m_lIconSize)
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eDIAmond]).Pointer.HorizSize =
                m_lIconSize;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eDIAmond]).Pointer.Pen.Color =
                Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eDIAmond]).Marks.Callout.InflateMargins =
                false;
            // IIf(m_lIconSize > 5, 5, m_lIconSize)

            tChartConcrol.Series.Add(new Steema.TeeChart.WPF.Styles.Points(tChartConcrol.Chart));
            //// Big transparent diamond
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eTransparentDiamond]).Pointer.Style =
                (Steema.TeeChart.WPF.Styles.PointerStyles) enSymbol.psDiamond;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eTransparentDiamond]).Pointer.Brush.
                Transparency = 100;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eTransparentDiamond]).Pointer.VertSize =
                m_lIconSize;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eTransparentDiamond]).Pointer.HorizSize =
                m_lIconSize;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eTransparentDiamond]).Pointer.Pen.Color =
                Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eTransparentDiamond]).Marks.Callout.
                InflateMargins = false;

            tChartConcrol.Series.Add(new Steema.TeeChart.WPF.Styles.Points(tChartConcrol.Chart));
            //// small filled diamond
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eSmallDiamond]).Pointer.Style =
                (Steema.TeeChart.WPF.Styles.PointerStyles) enSymbol.psDiamond;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eSmallDiamond]).Pointer.VertSize =
                Convert.ToInt32(m_lIconSize/2d);
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eSmallDiamond]).Pointer.HorizSize =
                Convert.ToInt32(m_lIconSize/2d);
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eSmallDiamond]).Pointer.Pen.Color =
                Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eSmallDiamond]).Marks.Callout.
                InflateMargins = false;

            tChartConcrol.Series.Add(new Steema.TeeChart.WPF.Styles.Points(tChartConcrol.Chart));
            //// small transparent diamond
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eTransparentSmallDiamond]).Pointer.Style
                =
                (Steema.TeeChart.WPF.Styles.PointerStyles) enSymbol.psDiamond;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eTransparentSmallDiamond]).Pointer.Brush.
                Transparency = 100;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eTransparentSmallDiamond]).Pointer.
                VertSize =
                Convert.ToInt32(m_lIconSize/2d);
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eTransparentSmallDiamond]).Pointer.
                HorizSize =
                Convert.ToInt32(m_lIconSize/2d);
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eTransparentSmallDiamond]).Pointer.Pen.
                Color = Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eTransparentSmallDiamond]).Marks.Callout.
                InflateMargins = false;

            tChartConcrol.Series.Add(new Steema.TeeChart.WPF.Styles.Points(tChartConcrol.Chart));
            //// Half up transparent triangle
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eUpHalfDiamond]).Pointer.Style =
                (Steema.TeeChart.WPF.Styles.PointerStyles) enSymbol.psTriangle;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eUpHalfDiamond]).Pointer.Brush.
                Transparency = 100;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eUpHalfDiamond]).Pointer.VertSize =
                Convert.ToInt32(m_lIconSize/2d);
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eUpHalfDiamond]).Pointer.HorizSize =
                m_lIconSize;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eUpHalfDiamond]).Pointer.Pen.Color =
                Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eUpHalfDiamond]).Marks.Callout.
                InflateMargins = false;

            tChartConcrol.Series.Add(new Steema.TeeChart.WPF.Styles.Points(tChartConcrol.Chart));
            //// Half down triangle
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eDownHalfDiamond]).Pointer.Style =
                (Steema.TeeChart.WPF.Styles.PointerStyles) enSymbol.psDownTriangle;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eDownHalfDiamond]).Pointer.VertSize =
                Convert.ToInt32(m_lIconSize/2d);
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eDownHalfDiamond]).Pointer.HorizSize =
                m_lIconSize;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eDownHalfDiamond]).Pointer.Pen.Color =
                Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eDownHalfDiamond]).Marks.Callout.
                InflateMargins = false;

            tChartConcrol.Series.Add(new Steema.TeeChart.WPF.Styles.Points(tChartConcrol.Chart));
            //// Cross diagonal
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCrossDiagonal]).Pointer.Style =
                (Steema.TeeChart.WPF.Styles.PointerStyles) enSymbol.psDiagCross;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCrossDiagonal]).Pointer.VertSize =
                m_lIconSize;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCrossDiagonal]).Pointer.HorizSize =
                m_lIconSize;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCrossDiagonal]).Pointer.Pen.Color =
                Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCrossDiagonal]).Marks.Callout.
                InflateMargins = false;

            tChartConcrol.Series.Add(new Steema.TeeChart.WPF.Styles.Gantt(tChartConcrol.Chart));
            //// Over lap drug push gannt
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eOverlap]).Pointer.VertSize = m_lIconSize;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eOverlap]).Pointer.Pen.Width = 1;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eOverlap]).Pointer.Pen.Style =
                DashStyles.Solid;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eOverlap]).ColorEach = false;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eOverlap]).Pointer.Pen.Color =
                Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eOverlap]).Marks.Callout.InflateMargins =
                false;

            tChartConcrol.Series.Add(new Steema.TeeChart.WPF.Styles.Gantt(tChartConcrol.Chart));
            //// Continues Validated
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eValidated]).Pointer.VertSize =
                Convert.ToInt32(m_lIconSize/2d); //+ 1
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eValidated]).Pointer.Pen.Width =
                Convert.ToInt32(m_lIconSize/6d);
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eValidated]).Pointer.Pen.Style =
                DashStyles.Solid;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eValidated]).ColorEach = false;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eValidated]).Pointer.Pen.Color =
                Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eValidated]).Marks.Callout.InflateMargins
                = false;

            tChartConcrol.Series.Add(new Steema.TeeChart.WPF.Styles.Gantt(tChartConcrol.Chart));
            //// Continues Initiated
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eInitiated]).Pointer.VertSize =
                Convert.ToInt32(m_lIconSize/2d); //2
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eInitiated]).Pointer.Pen.Width =
                Convert.ToInt32(m_lIconSize/6d); //2
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eInitiated]).Pointer.Pen.Style =
                DashStyles.Dot;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eInitiated]).Pointer.Brush.Style =
                HatchStyle.BackwardDiagonal;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eInitiated]).Pointer.Brush.Solid = false;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eInitiated]).Pointer.Brush.
                ForegroundColor = Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eInitiated]).ColorEach = false;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eInitiated]).Pointer.Pen.Color =
                Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eInitiated]).Marks.Callout.InflateMargins
                = false;

            tChartConcrol.Series.Add(new Steema.TeeChart.WPF.Styles.Points(tChartConcrol.Chart)); //// Change Up
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eChangeUpSeries]).Pointer.Style =
                (Steema.TeeChart.WPF.Styles.PointerStyles) enSymbol.psTriangle;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eChangeUpSeries]).Pointer.VertSize =
                Convert.ToInt32(m_lIconSize/2d);
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eChangeUpSeries]).Pointer.HorizSize =
                Convert.ToInt32(m_lIconSize/2d);
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eChangeUpSeries]).Pointer.Pen.Color =
                Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eChangeUpSeries]).Marks.Callout.
                InflateMargins = false;

            tChartConcrol.Series.Add(new Steema.TeeChart.WPF.Styles.Points(tChartConcrol.Chart));
            //// Change Down
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eChangeDownSeries]).Pointer.Style =
                (Steema.TeeChart.WPF.Styles.PointerStyles) enSymbol.psDownTriangle;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eChangeDownSeries]).Pointer.VertSize =
                Convert.ToInt32(m_lIconSize/2d);
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eChangeDownSeries]).Pointer.HorizSize =
                Convert.ToInt32(m_lIconSize/2d);
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eChangeDownSeries]).Pointer.Pen.Color =
                Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eChangeDownSeries]).Marks.Callout.
                InflateMargins = false;

            tChartConcrol.Series.Add(new Steema.TeeChart.WPF.Styles.Points(tChartConcrol.Chart));
            //// cardexed change Up
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCardexedChangeUpSeries]).Pointer.Style =
                (Steema.TeeChart.WPF.Styles.PointerStyles) enSymbol.psTriangle;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCardexedChangeUpSeries]).Pointer.
                VertSize =
                Convert.ToInt32(m_lIconSize/2d);
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCardexedChangeUpSeries]).Pointer.
                HorizSize =
                Convert.ToInt32(m_lIconSize/2d);
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCardexedChangeUpSeries]).Pointer.Pen.
                Color = Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCardexedChangeUpSeries]).Marks.Callout.
                InflateMargins = false;

            tChartConcrol.Series.Add(new Steema.TeeChart.WPF.Styles.Points(tChartConcrol.Chart));
            //// cardexed change Down
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCardexedChangeDownSeries]).Pointer.Style
                =
                (Steema.TeeChart.WPF.Styles.PointerStyles) enSymbol.psDownTriangle;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCardexedChangeDownSeries]).Pointer.
                VertSize =
                Convert.ToInt32(m_lIconSize/2d);
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCardexedChangeDownSeries]).Pointer.
                HorizSize =
                Convert.ToInt32(m_lIconSize/2d);
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCardexedChangeDownSeries]).Pointer.Pen.
                Color = Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCardexedChangeDownSeries]).Marks.Callout
                .InflateMargins = false;

            //// Must be last items
            tChartConcrol.Series.Add(new Steema.TeeChart.WPF.Styles.Gantt(tChartConcrol.Chart));
            //// Continues Pending
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.ePending]).Pointer.VertSize =
                Convert.ToInt32(m_lIconSize/2d);
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.ePending]).Pointer.Pen.Width =
                Convert.ToInt32(m_lIconSize/6d);
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.ePending]).Pointer.Pen.Style =
                DashStyles.Dot;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.ePending]).Pointer.Brush.Style =
                HatchStyle.BackwardDiagonal;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.ePending]).Pointer.Brush.Solid = false;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.ePending]).Pointer.Brush.ForegroundColor
                = Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.ePending]).ColorEach = false;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.ePending]).Pointer.Pen.Color =
                Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.ePending]).Marks.Callout.InflateMargins =
                false;

            tChartConcrol.Series.Add(new Steema.TeeChart.WPF.Styles.Points(tChartConcrol.Chart));
            //// cardexed stop \ start \ pause (or in SC)
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCardexedStartStopPauseResume]).Pointer.
                Style =
                (Steema.TeeChart.WPF.Styles.PointerStyles) enSymbol.psRectangle;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCardexedStartStopPauseResume]).Pointer.
                VertSize =
                Convert.ToInt32(m_lIconSize/2d);
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCardexedStartStopPauseResume]).Pointer.
                HorizSize = 1;
            //m_lIconSize / 2 '  IIf(m_lIconSize > 4, 4, m_lIconSize)
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCardexedStartStopPauseResume]).Pointer.
                Pen.Width = 1;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCardexedStartStopPauseResume]).Pointer.
                Pen.Color =
                Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCardexedStartStopPauseResume]).Pointer.
                Brush.Style =
                HatchStyle.Percent40;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCardexedStartStopPauseResume]).Pointer.
                Brush.Color =
                Colors.White;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eCardexedStartStopPauseResume]).Marks.
                Callout.InflateMargins = false;

            tChartConcrol.Series.Add(new Steema.TeeChart.WPF.Styles.Points(tChartConcrol.Chart));
            //// Stop \ start \ pause (validated)
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eStartStopPauseResume]).Pointer.Style =
                (Steema.TeeChart.WPF.Styles.PointerStyles) enSymbol.psRectangle;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eStartStopPauseResume]).Pointer.VertSize
                =
                Convert.ToInt32(m_lIconSize/2d);
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eStartStopPauseResume]).Pointer.HorizSize
                = 1;
            //m_lIconSize / 2 '  IIf(m_lIconSize > 4, 4, m_lIconSize)
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eStartStopPauseResume]).Pointer.Pen.Width
                = 1;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eStartStopPauseResume]).Pointer.Pen.Color
                = Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Points)
                tChartConcrol.Series[(int) EOTLFigure.eStartStopPauseResume]).Marks.Callout.
                InflateMargins = false;

            tChartConcrol.Series.Add(new Steema.TeeChart.WPF.Styles.Gantt(tChartConcrol.Chart));
            //// Continues Problematic
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eProblematic]).Pointer.VertSize =
                Convert.ToInt32(m_lIconSize/2d); //+ 1
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eProblematic]).Pointer.Pen.Width = 1;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eProblematic]).Pointer.Pen.Style =
                DashStyles.Solid;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eProblematic]).Pointer.Brush.Style =
                HatchStyle.Percent20;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eProblematic]).Pointer.Brush.Color =
                Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eProblematic]).Pointer.Brush.
                ForegroundColor = Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eProblematic]).ColorEach = false;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eProblematic]).Pointer.Pen.Color =
                Colors.Black;
            ((Steema.TeeChart.WPF.Styles.Gantt)
                tChartConcrol.Series[(int) EOTLFigure.eProblematic]).Marks.Callout.
                InflateMargins = false;

            tChartConcrol.Series[0].VertAxis = Steema.TeeChart.WPF.Styles.VerticalAxis.Right;
        }


        private void MainWindow_OnLoaded(object sender, RoutedEventArgs e)
        {
            InitTChartProperties();
            ResizeViewControls();

            SetTChartDefaults();
            CreateTchartSeries();

            tChartConcrol.Axes.Bottom.SetMinMax(0, 12);

            if (m_iRowHight != 0)
            {
                m_lDefaulRowNumber =
                    Convert.ToInt32(Math.Floor(((Canvas)tChartConcrol.Parent).Height / ((double)m_iRowHight)));
                m_lDefaulRowNumber = Convert.ToInt32(Math.Floor(this.ActualHeight / ((double)m_iRowHight)));
            }

            

        }

        private void BtnPaint_OnClick(object sender, RoutedEventArgs e)
        {
            tChartConcrol.AutoRepaint = false;
            using (StreamReader reader = new StreamReader(@"data.txt"))
            {
                while (true)
                {
                    string line = reader.ReadLine();
                    if (string.IsNullOrEmpty(line))
                    {
                        break;
                    }

                    List<double> data = line.Split(',').Select(Convert.ToDouble).ToList();

                    ((Steema.TeeChart.WPF.Styles.Gantt)tChartConcrol.Series[(int)EOTLFigure.eOverlap]).Add(data[0], data[2], data[1], "", Color.FromArgb(255,255,0,0));
                }
            }
            tChartConcrol.Invalidate();
            
        }
    }
}
